@@ -9,5 +9,5 @@ from .grid import Grid, RectilinearGrid, UniformGrid
 from .objects import Table, Texture
 from .pointset import PointGrid, PolyData, StructuredGrid, UnstructuredGrid, ExplicitStructuredGrid
 from .pyvista_ndarray import pyvista_ndarray
-from .common_data import *
-from .imaging import *
+from .common_data import perlin_noise
+from .imaging import sample_function
