@@ -6,6 +6,7 @@ import numpy as np
 
 import pyvista as pv
 from pyvista import examples
+
 from .logo import text_3d
 
 
@@ -30,6 +31,7 @@ def glyphs(grid_sz=3):
     --------
     >>> from pyvista import demos
     >>> mesh = demos.glyphs()
+    >>> mesh.plot()
 
     """
     n = 10
@@ -42,6 +44,7 @@ def glyphs(grid_sz=3):
     geoms = [pv.ParametricSuperToroid(n1=n1, n2=n2) for n1, n2 in params]
 
     # get dataset where to put glyphs
+    grid_sz = float(grid_sz)
     x, y, z = np.mgrid[:grid_sz, :grid_sz, :grid_sz]
     mesh = pv.StructuredGrid(x, y, z)
 
@@ -121,48 +124,48 @@ def orientation_cube():
 
     x_p = text_3d('X+', depth=0.2)
     x_p.points *= 0.45
-    x_p.rotate_y(90)
-    x_p.rotate_x(90)
-    x_p.translate(-np.array(x_p.center))
-    x_p.translate([0.5, 0, 0])
+    x_p.rotate_y(90, inplace=True)
+    x_p.rotate_x(90, inplace=True)
+    x_p.translate(-np.array(x_p.center), inplace=True)
+    x_p.translate([0.5, 0, 0], inplace=True)
     # x_p.point_data['mesh'] = 1
 
     x_n = text_3d('X-', depth=0.2)
     x_n.points *= 0.45
-    x_n.rotate_y(90)
-    x_n.rotate_x(90)
-    x_n.rotate_z(180)
-    x_n.translate(-np.array(x_n.center))
-    x_n.translate([-0.5, 0, 0])
+    x_n.rotate_y(90, inplace=True)
+    x_n.rotate_x(90, inplace=True)
+    x_n.rotate_z(180, inplace=True)
+    x_n.translate(-np.array(x_n.center), inplace=True)
+    x_n.translate([-0.5, 0, 0], inplace=True)
     # x_n.point_data['mesh'] = 2
 
     y_p = text_3d('Y+', depth=0.2)
     y_p.points *= 0.45
-    y_p.rotate_x(90)
-    y_p.rotate_z(180)
-    y_p.translate(-np.array(y_p.center))
-    y_p.translate([0, 0.5, 0])
+    y_p.rotate_x(90, inplace=True)
+    y_p.rotate_z(180, inplace=True)
+    y_p.translate(-np.array(y_p.center), inplace=True)
+    y_p.translate([0, 0.5, 0], inplace=True)
     # y_p.point_data['mesh'] = 3
 
     y_n = text_3d('Y-', depth=0.2)
     y_n.points *= 0.45
-    y_n.rotate_x(90)
-    y_n.translate(-np.array(y_n.center))
-    y_n.translate([0, -0.5, 0])
+    y_n.rotate_x(90, inplace=True)
+    y_n.translate(-np.array(y_n.center), inplace=True)
+    y_n.translate([0, -0.5, 0], inplace=True)
     # y_n.point_data['mesh'] = 4
 
     z_p = text_3d('Z+', depth=0.2)
     z_p.points *= 0.45
-    z_p.rotate_z(90)
-    z_p.translate(-np.array(z_p.center))
-    z_p.translate([0, 0, 0.5])
+    z_p.rotate_z(90, inplace=True)
+    z_p.translate(-np.array(z_p.center), inplace=True)
+    z_p.translate([0, 0, 0.5], inplace=True)
     # z_p.point_data['mesh'] = 5
 
     z_n = text_3d('Z-', depth=0.2)
     z_n.points *= 0.45
-    z_n.rotate_x(180)
-    z_n.translate(-np.array(z_n.center))
-    z_n.translate([0, 0, -0.5])
+    z_n.rotate_x(180, inplace=True)
+    z_n.translate(-np.array(z_n.center), inplace=True)
+    z_n.translate([0, 0, -0.5], inplace=True)
 
     return {'cube': cube,
             'x_p': x_p,
@@ -316,13 +319,12 @@ def plot_ants_plane(notebook=None):
        Rotate and translate ant so it is on the plane.
 
        >>> ant = examples.load_ant()
-       >>> ant.rotate_x(90)
-       >>> ant.translate([90, 60, 15])
+       >>> _ = ant.rotate_x(90, inplace=True)
+       >>> _ = ant.translate([90, 60, 15], inplace=True)
 
        Make a copy and add another ant.
 
-       >>> ant_copy = ant.copy()
-       >>> ant_copy.translate([30, 0, -10])
+       >>> ant_copy = ant.translate([30, 0, -10], inplace=False)
 
        Create plotting object.
 
@@ -356,12 +358,12 @@ def plot_ants_plane(notebook=None):
 
     # rotate and translate ant so it is on the plane
     ant = examples.load_ant()
-    ant.rotate_x(90)
-    ant.translate([90, 60, 15])
+    ant.rotate_x(90, inplace=True)
+    ant.translate([90, 60, 15], inplace=True)
 
     # Make a copy and add another ant
     ant_copy = ant.copy()
-    ant_copy.translate([30, 0, -10])
+    ant_copy.translate([30, 0, -10], inplace=True)
 
     # Create plotting object
     plotter = pv.Plotter(notebook=notebook)
@@ -402,7 +404,7 @@ def plot_beam(notebook=None):
             (-0.42546442225230097, 0.9024244135964158, -0.06789847673314177)]
 
     try:
-        import matplotlib
+        import matplotlib  # noqa
         cmap = 'bwr'
     except ImportError:  # pragma: no cover
         cmap = None
@@ -454,7 +456,7 @@ def plot_datasets(dataset_type=None):
 
     ###########################################################################
     # uniform grid
-    image = pv.UniformGrid((6, 6, 1))
+    image = pv.UniformGrid(dims=(6, 6, 1))
     image.spacing = (3, 2, 1)
 
     ###########################################################################
@@ -478,7 +480,7 @@ def plot_datasets(dataset_type=None):
 
     ###########################################################################
     # polydata
-    points = pv.PolyData([[1, 2, 2], [2, 2, 2]])
+    points = pv.PolyData([[1.0, 2.0, 2.0], [2.0, 2.0, 2.0]])
 
     line = pv.Line()
     line.points += np.array((2, 0, 0))
