@@ -2,3 +2,5 @@
 
 from pyvista.examples.downloads import *
 from pyvista.examples.examples import *
+from . import gltf
+from . import hdr
