@@ -3,12 +3,13 @@
 import warnings
 
 import numpy as np
+
 try:
     import pythreejs as tjs
 except ImportError:  # pragma: no cover
     raise ImportError('Please install pythreejs to use this feature')
 
-from ipywidgets import HBox, VBox, GridspecLayout
+from ipywidgets import GridspecLayout
 
 import pyvista as pv
 
@@ -166,7 +167,7 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr={}):
 
     * THREE.BufferGeometry expects position and index attributes
       representing a triangulated mesh points and face indices or just
-      a position array representing individual faces of a mesh. 
+      a position array representing individual faces of a mesh.
     * The normals attribute is needed for physically based rendering,
       but not for the other mesh types.
     * Colors must be a RGB array with one value per point.
@@ -273,6 +274,11 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr={}):
 
     if tjs_texture is not None:
         shared_attr['map'] = tjs_texture
+    else:
+        shared_attr['side'] = 'DoubleSide'
+
+    if prop.GetOpacity() < 1.0:
+        shared_attr['transparent'] = True
 
     if prop.GetInterpolation() == 3:  # using physically based rendering
         material = tjs.MeshPhysicalMaterial(flatShading=False,
@@ -442,13 +448,13 @@ def actor_to_mesh(actor, focal_point):
         if has_faces:
             surf = extract_surface_mesh(dataset)
             mesh = to_edge_mesh(surf, mapper, prop, use_edge_coloring=False)
+            meshes.append(mesh)
         elif np.any(dataset.lines):
             mesh = to_edge_mesh(dataset, mapper, prop, use_edge_coloring=False,
                                 use_lines=True)
+            meshes.append(mesh)
         else:  # pragma: no cover
-            warning.warn(f'Empty or unsupported dataset attached to actor')
-
-        meshes.append(mesh)
+            warnings.warn('Empty or unsupported dataset attached to actor')
 
     # the camera in three.js has no concept of a "focal point".  In
     # three.js, the scene is always centered at the origin, which
