@@ -52,7 +52,6 @@ import sys
 import time
 import zipfile
 
-
 FILENAME_EXTENSION = '.vtkjs'
 
 arrayTypesMapping = '  bBhHiIlLfdL'  # last one is idtype
@@ -621,7 +620,7 @@ def export_plotter_vtkjs(plotter, filename, compress_arrays=False):
         root_output_directory, f'{sceneName}{FILENAME_EXTENSION}')
 
     try:
-        import zlib
+        import zlib  # noqa
         compression = zipfile.ZIP_DEFLATED
     except:
         compression = zipfile.ZIP_STORED
