@@ -1,12 +1,11 @@
 """Wrap vtk.vtkRenderWindowInteractor."""
-import weakref
-import logging
 import collections.abc
 from functools import partial
-
-from pyvista.utilities import try_callback
+import logging
+import weakref
 
 from pyvista import _vtk
+from pyvista.utilities import try_callback
 
 log = logging.getLogger(__name__)
 log.setLevel('CRITICAL')
@@ -42,6 +41,13 @@ class RenderWindowInteractor():
         self._plotter = plotter
         self._click_observer = None
 
+        # Toggle interaction style when clicked on a visible chart (to
+        # enable interaction with visible charts)
+        # Current trigger is right click, alternatively double click triggers could be used:
+        # https://kitware.github.io/vtk-examples/site/Cxx/Interaction/DoubleClick/
+        self._context_style = _vtk.vtkContextInteractorStyle()
+        self.add_observer("RightButtonPressEvent", self._toggle_context_style)
+
     def add_key_event(self, key, callback):
         """Add a function to callback when the given key is pressed.
 
@@ -162,6 +168,31 @@ class RenderWindowInteractor():
             self._style_class = _style_factory(self._style)(self)
         self.interactor.SetInteractorStyle(self._style_class)
 
+    def _toggle_context_style(self, obj, event):
+        mouse_pos = self.get_event_position()
+        scene = None
+        for renderer in self._plotter.renderers:
+            if scene is None and renderer.IsInViewport(*mouse_pos):
+                scene = renderer._charts.toggle_interaction(mouse_pos)
+            else:
+                # Not in viewport or already an active chart found (in case they overlap), so disable interaction
+                renderer.charts.toggle_interaction(False)
+
+        self._context_style.SetScene(scene)  # Set scene to interact with or reset it to stop interaction (otherwise crash)
+        if scene is None and self._style == "Context":
+            # Switch back to previous interactor style
+            self._style = self._prev_style
+            self._style_class = self._prev_style_class
+            self._prev_style = None
+            self._prev_style_class = None
+        elif scene is not None and self._style != "Context":
+            # Enable context interactor style
+            self._prev_style = self._style
+            self._prev_style_class = self._style_class
+            self._style = "Context"
+            self._style_class = self._context_style
+        self.update_style()
+
     def enable_trackball_style(self):
         """Set the interactive style to Trackball Camera.
 
