@@ -1,7 +1,7 @@
 """Contains a dictionary that maps file extensions to VTK readers."""
 
-import pathlib
 import os
+import pathlib
 import warnings
 
 import numpy as np
@@ -206,6 +206,9 @@ def read_legacy(filename):
     reader.ReadAllNormalsOn()
     reader.ReadAllTCoordsOn()
     reader.ReadAllVectorsOn()
+    reader.ReadAllFieldsOn()
+    reader.ReadAllTensorsOn()
+
     # Perform the read
     output = standard_reader_routine(reader, None)
     if output is None:
@@ -279,7 +282,9 @@ def read(filename, attrs=None, force_ext=None, file_format=None):
        * ``'.foam'``
 
     .. note::
-       See https://github.com/nschloe/meshio for formats supported by ``meshio``.
+       See https://github.com/nschloe/meshio for formats supported by
+       ``meshio``. Be sure to install ``meshio`` with ``pip install
+       meshio`` if you wish to use it.
 
     Parameters
     ----------
@@ -578,10 +583,11 @@ def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None):
 
 def from_meshio(mesh):
     """Convert a ``meshio`` mesh instance to a PyVista mesh."""
-    from meshio.vtk._vtk import (
-        meshio_to_vtk_type,
-        vtk_type_to_numnodes,
-    )
+    try:  # meshio<5.0 compatibility
+        from meshio.vtk._vtk import meshio_to_vtk_type, vtk_type_to_numnodes
+    except ImportError:  # pragma: no cover
+        from meshio._vtk_common import meshio_to_vtk_type
+        from meshio.vtk._vtk_42 import vtk_type_to_numnodes
 
     # Extract cells from meshio.Mesh object
     offset = []
@@ -635,7 +641,14 @@ def from_meshio(mesh):
 
 def read_meshio(filename, file_format=None):
     """Read any mesh file using meshio."""
-    import meshio
+    try:
+        import meshio
+    except ImportError:  # pragma: no cover
+        raise ImportError(
+            "To use this feature install meshio with:\n\n"
+            "pip install meshio"
+        )
+
     # Make sure relative paths will work
     filename = os.path.abspath(os.path.expanduser(str(filename)))
     # Read mesh file
@@ -672,8 +685,18 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
     >>> pyvista.save_meshio('mymesh.inp', sphere)  # doctest:+SKIP
 
     """
-    import meshio
-    from meshio.vtk._vtk import vtk_to_meshio_type
+    try:
+        import meshio
+    except ImportError:  # pragma: no cover
+        raise ImportError(
+            "To use this feature install meshio with:\n\n"
+            "pip install meshio"
+        )
+
+    try:  # for meshio<5.0 compatibility
+        from meshio.vtk._vtk import vtk_to_meshio_type
+    except:  # pragma: no cover
+        from meshio._vtk_common import vtk_to_meshio_type
 
     # Make sure relative paths will work
     filename = os.path.abspath(os.path.expanduser(str(filename)))
