@@ -1,22 +1,24 @@
 """Supporting functions for polydata and grid objects."""
 
-import os
 import collections.abc
 import enum
 import logging
+import os
 import signal
 import sys
-from threading import Thread
 import threading
+from threading import Thread
 import traceback
 from typing import Optional
+import warnings
 
 import numpy as np
 
-from pyvista import _vtk
 import pyvista
-from .fileio import from_meshio
+from pyvista import _vtk
+
 from . import transformations
+from .fileio import from_meshio
 
 
 class FieldAssociation(enum.Enum):
@@ -429,7 +431,7 @@ def get_array_association(mesh, name, preference='cell', err=False) -> FieldAsso
     return matches[0]
 
 
-def vtk_points(points, deep=True):
+def vtk_points(points, deep=True, force_float=False):
     """Convert numpy array or array-like to a ``vtkPoints`` object.
 
     Parameters
@@ -442,6 +444,12 @@ def vtk_points(points, deep=True):
         Perform a deep copy of the array.  Only applicable if
         ``points`` is a :class:`numpy.ndarray`.
 
+    force_float : bool, optional
+        Casts the datatype to ``float32`` if points datatype is
+        non-float.  Set this to ``False`` to allow non-float types,
+        though this may lead to truncation of intermediate floats
+        when transforming datasets.
+
     Returns
     -------
     vtk.vtkPoints
@@ -463,6 +471,16 @@ def vtk_points(points, deep=True):
     if not np.issubdtype(points.dtype, np.number):
         raise TypeError('Points must be a numeric type')
 
+    if force_float:
+        if not np.issubdtype(points.dtype, np.floating):
+            warnings.warn(
+                'Points is not a float type. This can cause issues when '
+                'transforming or applying filters. Casting to '
+                '``np.float32``. Disable this by passing '
+                '``force_float=False``.'
+            )
+            points = points.astype(np.float32)
+
     # check dimensionality
     if points.ndim == 1:
         points = points.reshape(-1, 3)
@@ -885,7 +903,7 @@ def wrap(dataset):
         if dataset.ndim > 1 and dataset.ndim < 3 and dataset.shape[1] == 3:
             return pyvista.PolyData(dataset)
         elif dataset.ndim == 3:
-            mesh = pyvista.UniformGrid(dataset.shape)
+            mesh = pyvista.UniformGrid(dims=dataset.shape)
             mesh['values'] = dataset.ravel(order='F')
             mesh.active_scalars_name = 'values'
             return mesh
@@ -1031,7 +1049,7 @@ def fit_plane_to_points(points, return_meta=False):
 
     >>> pl = pyvista.Plotter()
     >>> _ = pl.add_mesh(plane, color='tan', style='wireframe', line_width=4)
-    >>> _ = pl.add_points(cloud, render_points_as_spheres=True, 
+    >>> _ = pl.add_points(cloud, render_points_as_spheres=True,
     ...                   color='r', point_size=30)
     >>> pl.show()
 
@@ -1234,7 +1252,7 @@ class ProgressMonitor():
     def __init__(self, algorithm, message="", scaling=100):
         """Initialize observer."""
         try:
-            from tqdm import tqdm
+            from tqdm import tqdm  # noqa
         except ImportError:
             raise ImportError("Please install `tqdm` to monitor algorithms.")
         self.event_type = _vtk.vtkCommand.ProgressEvent
@@ -1305,12 +1323,12 @@ def abstract_class(cls_):
 
 
 def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
-    """Rotate points angle (in deg) about an axis.
+    """Rotate points by angle about an axis.
 
     Parameters
     ----------
     points : numpy.ndarray
-        Array of points with shape ``(N, 3)``
+        Array of points with shape ``(N, 3)``.
 
     angle : float
         Rotation angle.
@@ -1319,8 +1337,8 @@ def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
         Updates points in-place while returning nothing.
 
     deg : bool, optional
-        If `True`, the angle is interpreted as degrees instead of
-        radians. Default is `True`.
+        If ``True``, the angle is interpreted as degrees instead of
+        radians. Default is ``True``.
 
     axis : str, optional
         Name of axis to rotate about. Valid options are ``'x'``, ``'y'``,
@@ -1334,6 +1352,7 @@ def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
     Examples
     --------
     Rotate a set of points by 90 degrees about the x-axis in-place.
+
     >>> import numpy as np
     >>> import pyvista
     >>> from pyvista import examples
