@@ -2,11 +2,12 @@
 
 from math import pi
 
+import numpy as np
 
 import pyvista
 from pyvista import _vtk
 from pyvista.utilities.errors import check_valid_vector
-import numpy as np
+
 from .geometric_objects import translate
 
 
@@ -29,7 +30,7 @@ def Spline(points, n_points=None):
 
     Examples
     --------
-    Construct a spline
+    Construct a spline.
 
     >>> import numpy as np
     >>> import pyvista as pv
@@ -184,10 +185,9 @@ def ParametricBohemianDome(a=None, **kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -249,7 +249,7 @@ def ParametricBoy(zscale=None, **kwargs):
 
     Examples
     --------
-    Create a ParametricBoy mesh
+    Create a ParametricBoy mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricBoy()
@@ -262,10 +262,9 @@ def ParametricBoy(zscale=None, **kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -286,9 +285,9 @@ def ParametricCatalanMinimal(**kwargs):
     pyvista.PolyData
         ParametricCatalanMinimal surface.
 
-    Example
-    -------
-    Create a ParametricCatalanMinimal mesh
+    Examples
+    --------
+    Create a ParametricCatalanMinimal mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricCatalanMinimal()
@@ -340,11 +339,11 @@ def ParametricConicSpiral(a=None, b=None, c=None, n=None, **kwargs):
     Returns
     -------
     pyvista.PolyData
-        ParametricConicSpiral surface
+        ParametricConicSpiral surface.
 
     Examples
     --------
-    Create a ParametricConicSpiral mesh
+    Create a ParametricConicSpiral mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricConicSpiral()
@@ -436,7 +435,7 @@ def ParametricDini(a=None, b=None, **kwargs):
 
     Examples
     --------
-    Create a ParametricDini mesh
+    Create a ParametricDini mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricDini()
@@ -491,7 +490,7 @@ def ParametricEllipsoid(xradius=None, yradius=None, zradius=None,
 
     Examples
     --------
-    Create a ParametricEllipsoid mesh
+    Create a ParametricEllipsoid mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricEllipsoid()
@@ -520,10 +519,9 @@ def ParametricEllipsoid(xradius=None, yradius=None, zradius=None,
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -585,7 +583,7 @@ def ParametricFigure8Klein(radius=None, **kwargs):
 
     Examples
     --------
-    Create a ParametricFigure8Klein mesh
+    Create a ParametricFigure8Klein mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricFigure8Klein()
@@ -598,10 +596,9 @@ def ParametricFigure8Klein(radius=None, **kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -620,7 +617,7 @@ def ParametricHenneberg(**kwargs):
 
     Examples
     --------
-    Create a ParametricHenneberg mesh
+    Create a ParametricHenneberg mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricHenneberg()
@@ -658,7 +655,7 @@ def ParametricKlein(**kwargs):
 
     Examples
     --------
-    Create a ParametricKlein mesh
+    Create a ParametricKlein mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricKlein()
@@ -669,10 +666,9 @@ def ParametricKlein(**kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -714,10 +710,9 @@ def ParametricKuen(deltav0=None, **kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -753,9 +748,7 @@ def ParametricMobius(radius=None, **kwargs):
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -833,10 +826,9 @@ def ParametricPseudosphere(**kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -1013,14 +1005,27 @@ def ParametricSuperEllipsoid(xradius=None, yradius=None, zradius=None,
     pyvista.PolyData
         ParametricSuperEllipsoid surface.
 
+    See Also
+    --------
+    pyvista.ParametricSuperToroid :
+        Toroidal equivalent of ParametricSuperEllipsoid.
+    pyvista.Superquadric :
+        Geometric object with additional parameters.
+
     Examples
     --------
-    Create a ParametricSuperEllipsoid mesh.
+    Create a ParametricSuperEllipsoid surface that looks like a box
+    with smooth edges.
 
     >>> import pyvista
-    >>> mesh = pyvista.ParametricSuperEllipsoid()
+    >>> mesh = pyvista.ParametricSuperEllipsoid(n1=0.02, n2=0.02)
     >>> mesh.plot(color='w', smooth_shading=True)
 
+    Create one that looks like a spinning top.
+
+    >>> mesh = pyvista.ParametricSuperEllipsoid(n1=4, n2=0.5)
+    >>> mesh.plot(color='w', smooth_shading=True, cpos='xz')
+
     """
     parametric_function = _vtk.vtkParametricSuperEllipsoid()
     if xradius is not None:
@@ -1094,12 +1099,19 @@ def ParametricSuperToroid(ringradius=None, crosssectionradius=None,
     pyvista.PolyData
         ParametricSuperToroid surface.
 
+    See Also
+    --------
+    pyvista.ParametricSuperEllipsoid :
+        Ellipsoidal equivalent of ParametricSuperToroid.
+    pyvista.Superquadric :
+        Geometric object with additional parameters.
+
     Examples
     --------
     Create a ParametricSuperToroid mesh.
 
     >>> import pyvista
-    >>> mesh = pyvista.ParametricSuperToroid()
+    >>> mesh = pyvista.ParametricSuperToroid(n1=2, n2=0.3)
     >>> mesh.plot(color='w', smooth_shading=True)
 
     """
@@ -1127,10 +1139,9 @@ def ParametricSuperToroid(ringradius=None, crosssectionradius=None,
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -1172,10 +1183,9 @@ def ParametricTorus(ringradius=None, crosssectionradius=None, **kwargs):
 
     center = kwargs.pop('center', [0., 0., 0.])
     direction = kwargs.pop('direction', [1., 0., 0.])
+    kwargs.setdefault('clean', True)
     surf = surface_from_para(parametric_function, **kwargs)
-
     translate(surf, center, direction)
-
     return surf
 
 
@@ -1233,7 +1243,8 @@ def parametric_keywords(parametric_function, min_u=0, max_u=2*pi,
     parametric_function.SetClockwiseOrdering(clockwise)
 
 
-def surface_from_para(parametric_function, u_res=100, v_res=100, w_res=100):
+def surface_from_para(parametric_function, u_res=100, v_res=100, w_res=100,
+                      clean=False):
     """Construct a mesh from a parametric function.
 
     Parameters
@@ -1250,6 +1261,10 @@ def surface_from_para(parametric_function, u_res=100, v_res=100, w_res=100):
     w_res : int, optional
         Resolution in the w direction.
 
+    clean : bool, optional
+        Clean and merge duplicate points to avoid "creases" when
+        plotting with smooth shading.
+
     Returns
     -------
     pyvista.PolyData
@@ -1263,4 +1278,13 @@ def surface_from_para(parametric_function, u_res=100, v_res=100, w_res=100):
     para_source.SetVResolution(v_res)
     para_source.SetWResolution(w_res)
     para_source.Update()
-    return pyvista.wrap(para_source.GetOutput())
+    surf = pyvista.wrap(para_source.GetOutput())
+    if clean:
+        surf = surf.clean(
+            tolerance=1E-7,  # determined experimentally
+            absolute=False,
+            lines_to_points=False,
+            polys_to_lines=False,
+            strips_to_polys=False,
+        )
+    return surf
